Change linkage of ipmid_get_sdbus_plus_handler() to libipmid.so

ipmid_get_sdbus_plus_handler() was re-added to be a part of
systemintfcmds where it was used. This moves it to libipmid.so
because that is where symbols used by both ipmid and the providers
should be.

Because ipmid_get_sdbus_plus_handler() relies on the io service and the
main sdbus::asio::connection is also right there, this moves those
symbols to libipmid as well to keep coherent.

Change-Id: Ib125a0c217c8bcf47a8a4bd0c557eb69e928245b
Signed-off-by: Vernon Mauery <vernon.mauery@linux.intel.com>
diff --git a/include/ipmid/api.hpp b/include/ipmid/api.hpp
index 47dc04d..b691bed 100644
--- a/include/ipmid/api.hpp
+++ b/include/ipmid/api.hpp
@@ -221,8 +221,8 @@
 
 } // namespace ipmi
 
-// any client can interact with the main asio service
-std::shared_ptr<boost::asio::io_service> getIoService();
+// any client can interact with the main asio context
+std::shared_ptr<boost::asio::io_context> getIoContext();
 
 // any client can interact with the main sdbus
 std::shared_ptr<sdbusplus::asio::connection> getSdBus();
@@ -239,5 +239,5 @@
 template <typename WorkFn>
 static inline void post_work(WorkFn work)
 {
-    getIoService()->post(std::forward<WorkFn>(work));
+    getIoContext()->post(std::forward<WorkFn>(work));
 }